﻿// =================================================================================================
// Copyright © Woodlands Solutions, LLC. 2008-2012.  All Rights Reserved.
// Author :  Steve Wall
// Date   :  09/13/2012
// =================================================================================================

#region Using Statements
using System;

using Infragistics.Calculations.Engine;
#endregion

namespace XamFormulaEditor
{
    public class IndexSettleFunction : CalculationFunction
    {
        public override string[] ArgDescriptors
        {
            get { return new string[] { "Index definition", "Number of settles offset", "Number of settles to average" }; }
        }

        public override string[] ArgList
        {
            get { return new string[] { "Index", "NumSettlesOffset", "NumSettlesToAvg" }; }
        }

        public override string Category
        {
            get { return "Phoenix"; }
        }

        public override string Description
        {
            get { return "This function calculates the index price based on the supplied parameters."; }
        }

        public override int MaxArgs
        {
            get { return 3; }
        }

        public override int MinArgs
        {
            get { return 1; }
        }

        public override string Name
        {
            get { return "IndexSettle"; }
        }

        protected override CalculationValue Evaluate(CalculationNumberStack numberStack, int argumentCount)
        {
            #region Get arguments from numberStack
            CalculationValue numSettlesAvgCalcValue = null;
            CalculationValue numSettlesOffsetCalcValue = null;

            if (numberStack.Count() == 3)
            {
                numSettlesAvgCalcValue = numberStack.Pop();
                numSettlesOffsetCalcValue = numberStack.Pop();
            }

            CalculationValue indexDefCalcValue = numberStack.Pop();
            #endregion

            #region Convert arguments into something usable
            string indexDefinitionSd = null;
            int? numSettlesOffset = 0;
            int? numSettlesAvg = 1;
            int intVal;

            if ((indexDefCalcValue != null) && (indexDefCalcValue.Value != null))
            {
                indexDefinitionSd = indexDefCalcValue.Value.ToString();
            }

            if ((numSettlesOffsetCalcValue != null) && (numSettlesOffsetCalcValue.Value != null) && (int.TryParse(numSettlesOffsetCalcValue.ToString(), out intVal)))
            {
                numSettlesOffset = intVal;
            }

            if ((numSettlesAvgCalcValue != null) && (numSettlesAvgCalcValue.Value != null) && (int.TryParse(numSettlesAvgCalcValue.ToString(), out intVal)))
            {
                numSettlesAvg = intVal;
            }
            #endregion

            #region Validate inputs
            if (string.IsNullOrEmpty(indexDefinitionSd))
            {
                throw new Exception("Index definition must be supplied to function.");
            }
            #endregion

            return new CalculationValue(3.75);
        }
    }
}
