﻿// =================================================================================================
// Copyright © Woodlands Solutions, LLC. 2008-2012.  All Rights Reserved.
// Author :  Steve Wall
// Date   :  09/13/2012
// =================================================================================================

#region Using Statements
using System;
using System.ComponentModel;
using System.Windows;
using System.Windows.Controls;

using Infragistics.Calculations;
using Infragistics.Windows;
using Infragistics.Controls.Primitives;
using Infragistics.Controls.Menus;
using Infragistics.Controls.Interactions.Primitives;
#endregion

namespace XamFormulaEditor
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        XamCalculationManager m_CalcManager;

        public MainWindow()
        {
            try
            {
                InitializeComponent();

                // Get reference to XamCalculationManager resource
                m_CalcManager = MainWindowGrid.Resources["FormulaCalcManager"] as XamCalculationManager;
                
                if (m_CalcManager != null)
                {
                    // Register some sample custom function
                    m_CalcManager.RegisterUserDefinedFunction(new IndexSettleFunction());

                    // Add some sample named references
                    m_CalcManager.NamedReferences = new NamedReferenceCollection();
                    for (int i = 0; i < 5; i++)
                    {
                        string referenceId = string.Format("Index{0}", i);
                        string value = string.Format("Price Index {0}", i);
                        m_CalcManager.NamedReferences.Add(new NamedReference() { ReferenceId = referenceId, Category = "Phoenix Index", Value = value });
                    }
                }

                LoadAndBindData();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "XamFormulaEditor Test", MessageBoxButton.OK, MessageBoxImage.Error);
            }
        }

        private void LoadAndBindData()
        {
            BindingList<Deal> ls = new BindingList<Deal>();
            ls.Add(new Deal(new DateTime(2012, 10, 1), new DateTime(2012, 10, 31), 100, 3.50, string.Empty));
            ls.Add(new Deal(new DateTime(2012, 11, 1), new DateTime(2012, 11, 30), 150, 3.25, string.Empty));
            ls.Add(new Deal(new DateTime(2012, 12, 1), new DateTime(2012, 12, 31), 200, 3.00, string.Empty));
            ls.Add(new Deal(new DateTime(2013, 01, 1), new DateTime(2013, 01, 31), 150, 3.25, string.Empty));
            ls.Add(new Deal(new DateTime(2013, 02, 1), new DateTime(2013, 01, 28), 100, 3.50, string.Empty));
            DataGrid.DataSource = ls;
        }

        private void FormulaEditor_FormulaEditorDialogDisplaying(object sender, Infragistics.Controls.Interactions.FormulaEditorDialogDisplayingEventArgs e)
        {
            Dispatcher.BeginInvoke(new Action(() =>
            {
                ComboBox cb = Utilities.GetDescendantFromName(e.Dialog as DependencyObject, "OperandSearchFilterComboBox") as ComboBox;
                cb.SelectedIndex = 3;
                cb.IsEnabled = false;

                EmbeddedTextBox etb = Utilities.GetDescendantFromName(e.Dialog as DependencyObject, "OperandSearchTextBox") as EmbeddedTextBox;
                etb.IsReadOnly = true;

                XamDataTree xdt = Utilities.GetDescendantFromName(e.Dialog as DependencyObject, "OperandTree") as XamDataTree;
                (xdt.ItemsSource as FilteredCollection<OperandInfo>).ApplyFilter(t => t.Name != "Controls");

            }), System.Windows.Threading.DispatcherPriority.SystemIdle, null);
        }
    }
}
